agentle.agents.conversations.local\_conversation\_store
=======================================================

.. automodule:: agentle.agents.conversations.local_conversation_store

   
   .. rubric:: Functions

   .. autosummary::
   
      override
   
   .. rubric:: Classes

   .. autosummary::
   
      AssistantMessage
      ConversationStore
      DeveloperMessage
      LocalConversationStore
      MutableMapping
      MutableSequence
      Sequence
      UserMessage
   